import * as i0 from '@angular/core';
import { Component, ViewContainerRef, ViewChildren, NgModule } from '@angular/core';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { BaseUIComponent, queryValue, BindingProperties, propDescription, PropTypes, PropertyCategories, createComponent, StyleProperties, CoreService, toXMLResult, DynamicComponentsCoreModule } from '@ngx-dynamic-components/core';
import * as i1 from '@ng-select/ng-select';
import { NgSelectModule } from '@ng-select/ng-select';
import { setTheme } from 'ngx-bootstrap/utils';
import * as i1$1 from 'ngx-bootstrap/tabs';
import { TabsModule } from 'ngx-bootstrap/tabs';
import { __decorate, __metadata } from 'tslib';
import { Subject } from 'rxjs';
import { debounceTime, distinctUntilChanged } from 'rxjs/operators';

const packageName = 'bootstrap';

const example1 = {
    uiModel: `
    <div class="flex-column">
      <div class="form-group">
        <label class="col-form-label" width="60px">Select Option</label>
        <ng-select width="300px" binding="$.selectedOption">
          <option value="o1">Option 1</option>
          <option value="o2">Option 2</option>
        </ng-select>
      </div>
    </div>
  `,
    dataModel: {},
    title: 'Static dropdown declaration',
};
const example2 = {
    uiModel: `
    <div class="flex-column">
      <div class="form-group">
        <label class="col-form-label" width="60px">Select</label>
        <ng-select width="300px" itemsSource="$.list" binding="$.selected"></ng-select>
      </div>
    </div>
  `,
    dataModel: {
        list: [{ label: 'Data 1', value: 'd1' }, { label: 'Data 2', value: 'd2' }]
    },
    title: 'Dropdown options binded to dataModel',
};
const example3 = {
    uiModel: `
    <div class="flex-column">
      <div class="form-group">
        <label class="col-form-label" width="60px">Country</label>
        <ng-select onSelect="countryChanged" width="300px" binding="$.country">
          <option value="uk">United Kingdom</option>
          <option value="ua">Ukraine</option>
        </ng-select>
      </div>
      <div class="form-group">
        <label class="col-form-label" width="60px">City</label>
        <ng-select width="300px" itemsSource="$.cities" binding="$.city"></ng-select>
      </div>
    </div>
  `,
    dataModel: {},
    scripts: `
  # Evaluated with JSPython https://jspython.dev/

  def countryChanged():
    dataModel.city = null
    if dataModel.country == null:
      dataModel.cities = []
    if dataModel.country == "uk":
      dataModel.cities = [{label: "London", value: "lon"}, {label: "Liverpool", value: "liv"}]
    if dataModel.country == "ua":
      dataModel.cities = [{label: "Kyiv", value: "kyiv"}, {label: "Lviv", value: "lvi"}]
  `,
    title: 'Dependency between dropdowns',
    description: 'Handles change event from first dropdown and changes values in second.'
};
const example4 = {
    uiModel: `
    <div class="flex-column">
      <div class="form-group">
        <label class="col-form-label" width="60px">Select</label>
        <ng-select width="300px" 
          itemsSource="$.list" 
          typeahead="onTypeahead(searchTerm)" 
          debounceTime="1000" 
          binding="$.selected"
          change="onChange()">
        </ng-select>
      </div>
      
      <text binding="$.selected"></text>
    </div>
  `,
    dataModel: {},
    scripts: `
  async def onTypeahead():
    if searchTerm != null:
      # can be server-side call
      dataModel.list = [
        {label: searchTerm + ' 2', value: searchTerm + ' 2'},
        {label: searchTerm + ' 2', value: searchTerm + ' 2'}
      ]
  
  async def onChange():
    print('Selected value: ', dataModel.selected)
  `,
    title: 'drop-down with typeahead and debounceTime',
};
var example$1 = [example1, example1, example2, example4];

// eslint-disable-next-line @angular-eslint/no-conflicting-lifecycle
class SelectComponent extends BaseUIComponent {
    constructor() {
        super(...arguments);
        this.searchText$ = new Subject();
        this.loading = false;
    }
    onSelect(evt) {
        this.changedDataModel.emit(this.dataModel);
        this.emitEvent(this.properties.change, evt);
    }
    get debounceTime() {
        return this.properties.debounceTime ? parseInt(this.properties.debounceTime, 10) : 500;
    }
    // eslint-disable-next-line @angular-eslint/use-lifecycle-interface
    async ngOnInit() {
        await super.ngOnInit();
        this.searchText$
            .pipe(debounceTime(this.debounceTime), distinctUntilChanged())
            .subscribe(data => this.emitEvent(this.properties.typeahead, data));
    }
    emitEvent(prop, param) {
        super.emitEvent(prop, param);
    }
    get selectStyles() {
        if (this.properties.selectHeight) {
            return {
                height: this.properties.selectHeight
            };
        }
        return null;
    }
    get options() {
        const src = this.properties.itemsSource;
        if (Array.isArray(src)) {
            return src;
        }
        if (typeof src === 'string' && src.startsWith('$.')) {
            return queryValue(this.dataModel, src);
        }
    }
}
SelectComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: SelectComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
SelectComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.0", type: SelectComponent, selector: "dc-select", usesInheritance: true, ngImport: i0, template: `
  <ng-select [items]="options" [ngStyle]="selectStyles"
      [(ngModel)]="componentDataModel" [bindLabel]="properties.bindLabel"
      [typeahead]="searchText$"
      [bindValue]="properties.bindValue || 'value'" [placeholder]="properties.placeholder"
      (add)="emitEvent(properties.add, $event)"
      (blur)="emitEvent(properties.blur, $event)"
      (change)="onSelect($event)"
      (close)="emitEvent(properties.close, $event)"
      (clear)="emitEvent(properties.clear, $event)"
      (focus)="emitEvent(properties.focus, $event)"
      (search)="emitEvent(properties.search, $event)"
      (open)="emitEvent(properties.open, $event)"
      (remove)="emitEvent(properties.remove, $event)"
      (scroll)="emitEvent(properties.scroll, $event)"
      (scrollToEnd)="emitEvent(properties.scrollToEnd, $event)"></ng-select>

    `, isInline: true, styles: [":host ::ng-deep .ng-select.ng-select-single .ng-select-container{height:inherit;min-height:30px}\n"], components: [{ type: i1.NgSelectComponent, selector: "ng-select", inputs: ["bindLabel", "bindValue", "markFirst", "placeholder", "notFoundText", "typeToSearchText", "addTagText", "loadingText", "clearAllText", "appearance", "dropdownPosition", "appendTo", "loading", "closeOnSelect", "hideSelected", "selectOnTab", "openOnEnter", "maxSelectedItems", "groupBy", "groupValue", "bufferAmount", "virtualScroll", "selectableGroup", "selectableGroupAsModel", "searchFn", "trackByFn", "clearOnBackspace", "labelForId", "inputAttrs", "tabIndex", "readonly", "searchWhileComposing", "minTermLength", "editableSearchTerm", "keyDownFn", "typeahead", "multiple", "addTag", "searchable", "clearable", "isOpen", "items", "compareWith", "clearSearchOnAdd"], outputs: ["blur", "focus", "change", "open", "close", "search", "clear", "add", "remove", "scroll", "scrollToEnd"] }], directives: [{ type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: SelectComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'dc-select',
                    template: `
  <ng-select [items]="options" [ngStyle]="selectStyles"
      [(ngModel)]="componentDataModel" [bindLabel]="properties.bindLabel"
      [typeahead]="searchText$"
      [bindValue]="properties.bindValue || 'value'" [placeholder]="properties.placeholder"
      (add)="emitEvent(properties.add, $event)"
      (blur)="emitEvent(properties.blur, $event)"
      (change)="onSelect($event)"
      (close)="emitEvent(properties.close, $event)"
      (clear)="emitEvent(properties.clear, $event)"
      (focus)="emitEvent(properties.focus, $event)"
      (search)="emitEvent(properties.search, $event)"
      (open)="emitEvent(properties.open, $event)"
      (remove)="emitEvent(properties.remove, $event)"
      (scroll)="emitEvent(properties.scroll, $event)"
      (scrollToEnd)="emitEvent(properties.scrollToEnd, $event)"></ng-select>

    `,
                    styles: [`
    :host ::ng-deep .ng-select.ng-select-single .ng-select-container {
      height: inherit;
      min-height: 30px;
    }
  `]
                }]
        }] });
class SelectProperties extends BindingProperties {
}
__decorate([
    propDescription({
        description: 'Select options or binding to dataModel.',
        example: '[{label: "One", value: 1}]',
    }),
    __metadata("design:type", Object)
], SelectProperties.prototype, "itemsSource", void 0);
__decorate([
    propDescription({
        description: 'Select height.',
        example: '30px',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "selectHeight", void 0);
__decorate([
    propDescription({
        description: 'Placeholder',
        example: 'Select name',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "placeholder", void 0);
__decorate([
    propDescription({
        description: 'Label property.',
        example: 'name',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "bindLabel", void 0);
__decorate([
    propDescription({
        description: 'Value property.',
        example: 'id',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "bindValue", void 0);
__decorate([
    propDescription({
        description: 'Allows to select multiple items.',
        example: 'true'
    }),
    __metadata("design:type", Boolean)
], SelectProperties.prototype, "multiple", void 0);
__decorate([
    propDescription({
        description: 'Output add event handler.',
        example: 'onAdd()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "add", void 0);
__decorate([
    propDescription({
        description: 'Output blur event handler.',
        example: 'onBlur()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "blur", void 0);
__decorate([
    propDescription({
        description: 'Output change event handler.',
        example: 'onChange()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "change", void 0);
__decorate([
    propDescription({
        description: 'debounceTime in miliseconds. Used only with `typeahead` event handler. Default is 500 (miliseconds)',
        example: '500',
        type: PropTypes.PROPERTY
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "debounceTime", void 0);
__decorate([
    propDescription({
        description: 'Typeahead event handler.',
        example: 'onTypeahead()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "typeahead", void 0);
__decorate([
    propDescription({
        description: 'Output close event handler.',
        example: 'onClose()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "close", void 0);
__decorate([
    propDescription({
        description: 'Output clear event handler.',
        example: 'onClear()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "clear", void 0);
__decorate([
    propDescription({
        description: 'Output focus event handler.',
        example: 'onFocus()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "focus", void 0);
__decorate([
    propDescription({
        description: 'Output search event handler.',
        example: 'onSearch()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "search", void 0);
__decorate([
    propDescription({
        description: 'Output open event handler.',
        example: 'onOpen()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "open", void 0);
__decorate([
    propDescription({
        description: 'Output remove event handler.',
        example: 'onRemove()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "remove", void 0);
__decorate([
    propDescription({
        description: 'Output scroll event handler.',
        example: 'onScroll()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "scroll", void 0);
__decorate([
    propDescription({
        description: 'Output scrollToEnd event handler.',
        example: 'onScrollToEnd()',
        type: PropTypes.EVENT
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "scrollToEnd", void 0);
const selectDescriptor = {
    name: 'ng-select',
    label: 'UI Select Input',
    packageName,
    category: "Basic" /* Basic */,
    description: 'NG Select component',
    itemProperties: SelectProperties,
    component: SelectComponent,
    example: example$1,
    parseUIModel(xmlRes) {
        const itemProperties = {};
        if (!xmlRes.attrs.itemsSource && xmlRes.childNodes) {
            itemProperties.itemsSource = xmlRes.childNodes.map(r => ({ label: r._, value: r.$ && r.$.hasOwnProperty('value') ? r.$.value : r._ }));
            xmlRes.childNodes = null;
        }
        itemProperties.multiple = xmlRes.attrs.multiple === 'true';
        return {
            type: 'ng-select',
            itemProperties
        };
    },
    defaultModel: `<ng-select width="100px" itemsSource="$.list" binding="$.value"></ng-select>`,
    propertiesDescriptor: [
        ['selectHeight', { name: 'selectHeight', label: 'Select Height', category: PropertyCategories.Layout }],
    ],
    children: [{
            tag: 'option',
            properties: [{
                    name: 'value',
                    label: 'Option value'
                }]
        }]
};

class TabsComponent extends BaseUIComponent {
    async ngOnInit() { }
    async ngAfterViewInit() {
        this.vContainers.forEach((vc, i) => createComponent(this, this.uiModel.children[i], vc));
        this.setHostStyles();
        this.emitEvent(this.properties.onInit);
    }
}
TabsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: TabsComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
TabsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.0", type: TabsComponent, selector: "dc-tabs-ui", viewQueries: [{ propertyName: "vContainers", predicate: ["vc"], descendants: true, read: ViewContainerRef }], usesInheritance: true, ngImport: i0, template: `
    <tabset class="tabset-fx w-100 overflow-auto nav-tabs-boxed">
      <tab *ngFor="let item of uiModel.children; let i = index" [heading]="item.itemProperties.header || 'Tab ' + (i + 1)">
        <ng-container #vc></ng-container>
      </tab>
    </tabset>
  `, isInline: true, components: [{ type: i1$1.TabsetComponent, selector: "tabset", inputs: ["vertical", "justified", "type"] }], directives: [{ type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i1$1.TabDirective, selector: "tab, [tab]", inputs: ["customClass", "active", "removable", "heading", "id", "disabled"], outputs: ["selectTab", "deselect", "removed"], exportAs: ["tab"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: TabsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'dc-tabs-ui',
                    template: `
    <tabset class="tabset-fx w-100 overflow-auto nav-tabs-boxed">
      <tab *ngFor="let item of uiModel.children; let i = index" [heading]="item.itemProperties.header || 'Tab ' + (i + 1)">
        <ng-container #vc></ng-container>
      </tab>
    </tabset>
  `
                }]
        }], propDecorators: { vContainers: [{
                type: ViewChildren,
                args: ['vc', { read: ViewContainerRef }]
            }] } });
class TabsProperties extends StyleProperties {
}
const example = {
    title: 'Tabs group example',
    uiModel: `
  <tab-container width="100%" height="100%" margin="8px">
		<tab header="Test tab" padding="0.5rem">
			<text text-style="h1">Tab 1 static text content</text>
		</tab>
    <tab header="Btn tab" class="align-items-start p-2 flex-column">
      <text text-style="h1">Button content</text>
      <button class="btn btn-primary mr-2" onClick="button1_Click">Click</button>
      <div>
        <h4>ClickCount:</h4>
        <text text-style="h4">$.clickCount</text>
      </div>
		</tab>
	</tab-container>
  `,
    scripts: `
  def button1_Click():
    print("button1_Click")
    if dataModel.clickCount == null:
      dataModel.clickCount = 0
    dataModel.clickCount = dataModel.clickCount + 1
  `,
    dataModel: {
        clickCount: 2
    }
};
const tabsDescriptor = {
    name: 'tab-container',
    label: 'Tabs container (Bootstrap)',
    packageName,
    category: "Containers" /* Containers */,
    description: 'Tabs component',
    itemProperties: TabsProperties,
    component: TabsComponent,
    example,
    parseUIModel(xmlData) {
        const children = xmlData.childNodes.map(child => {
            const itemProperties = child.$;
            itemProperties.height = '100%';
            itemProperties.width = '100%';
            return {
                type: 'section',
                children: child.$$.map((r) => CoreService.getUIModel(toXMLResult(r))),
                itemProperties
            };
        });
        return {
            type: 'tab-container',
            children
        };
    },
    children: [{
            tag: 'tab',
            hasChildren: true,
            properties: [{
                    name: 'header',
                    label: 'Tab title'
                }]
        }],
    defaultModel: `<tab-container width="100%" height="100%" margin="8px">
  <tab header="Tab 1" padding="0.5rem">
    <text text-style="h1">Tab 1 static text content</text>
  </tab>
  <tab header="Tab 2" padding="0.5rem">
    <text text-style="h1">Tab 2 static text content</text>
  </tab>
</tab-container>`
};

const COMPONENTS_LIST = [
    tabsDescriptor,
    selectDescriptor
];
// Register components.
function registerComponents() {
    COMPONENTS_LIST.forEach(component => CoreService.registerComponent(component));
}
function getCategories() {
    const categories = COMPONENTS_LIST.reduce((map, desc) => {
        map[desc.category] = map[desc.category] || [];
        map[desc.category].push(desc);
        return map;
    }, {});
    return Object.entries(categories).map(([key, val]) => ({
        name: key,
        components: val,
        packageName
    }));
}

const tabsModuleForRoot = TabsModule.forRoot();
class DynamicComponentsBootstrapModule {
    constructor() {
        setTheme('bs4');
        registerComponents();
    }
}
DynamicComponentsBootstrapModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: DynamicComponentsBootstrapModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DynamicComponentsBootstrapModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: DynamicComponentsBootstrapModule, declarations: [SelectComponent, TabsComponent], imports: [DynamicComponentsCoreModule,
        CommonModule,
        FormsModule,
        NgSelectModule, i1$1.TabsModule] });
DynamicComponentsBootstrapModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: DynamicComponentsBootstrapModule, imports: [[
            DynamicComponentsCoreModule,
            CommonModule,
            FormsModule,
            NgSelectModule,
            tabsModuleForRoot
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: DynamicComponentsBootstrapModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SelectComponent, TabsComponent],
                    imports: [
                        DynamicComponentsCoreModule,
                        CommonModule,
                        FormsModule,
                        NgSelectModule,
                        tabsModuleForRoot
                    ]
                }]
        }], ctorParameters: function () { return []; } });

/*
 * Public API Surface of bootstrap
 */

/**
 * Generated bundle index. Do not edit.
 */

export { COMPONENTS_LIST, DynamicComponentsBootstrapModule, SelectComponent, TabsComponent, getCategories, tabsModuleForRoot };
//# sourceMappingURL=ngx-dynamic-components-bootstrap.mjs.map
